Philipp Hörist pushed to branch master at gajim / gajim

Commits:
04904140 by Philipp Hörist at 2017-10-29T00:37:05+02:00
Fix saving MUC-PMs

If the JID is not in the DB we need a type to insert

- - - - -


1 changed file:

- gajim/common/logger.py


Changes:

=====================================
gajim/common/logger.py
=====================================
--- a/gajim/common/logger.py
+++ b/gajim/common/logger.py
@@ -290,13 +290,17 @@ class Logger:
 
         :param jid:     The JID
 
-        :param type_:   The JIDConstant type
+        :param kind:    The KindConstant
+
+        :param type_:   The JIDConstant
 
         return the jid id
         """
 
         if kind in (KindConstant.GC_MSG, KindConstant.GCSTATUS):
             type_ = JIDConstant.ROOM_TYPE
+        elif kind is not None:
+            type_ = JIDConstant.NORMAL_TYPE
 
         result = self._jid_ids.get(jid, None)
         if result is not None:



View it on GitLab: 
https://dev.gajim.org/gajim/gajim/commit/049041407919a0d58790ccac7be1eab7b3f0d88a

---
View it on GitLab: 
https://dev.gajim.org/gajim/gajim/commit/049041407919a0d58790ccac7be1eab7b3f0d88a
You're receiving this email because of your account on dev.gajim.org.
_______________________________________________
Commits mailing list
[email protected]
https://lists.gajim.org/cgi-bin/listinfo/commits

Reply via email to